qipipe - Quantitative Imaging pipeline
======================================

Quantitative Imaging pipeline. See the
`documentation <http://qipipe.readthedocs.org/en/latest/>`_
for more information.
